import pprint
import re  # noqa: F401

import six

class Health(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'details': 'dict(str, object)',
        'error_message': 'str',
        'healthy': 'bool'
    }

    attribute_map = {
        'details': 'details',
        'error_message': 'errorMessage',
        'healthy': 'healthy'
    }

    def __init__(self, details=None, error_message=None, healthy=None):  # noqa: E501
        """Health - a model defined in Swagger"""  # noqa: E501
        self._details = None
        self._error_message = None
        self._healthy = None
        self.discriminator = None
        if details is not None:
            self.details = details
        if error_message is not None:
            self.error_message = error_message
        if healthy is not None:
            self.healthy = healthy

    @property
    def details(self):
        """Gets the details of this Health.  # noqa: E501


        :return: The details of this Health.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this Health.


        :param details: The details of this Health.  # noqa: E501
        :type: dict(str, object)
        """

        self._details = details

    @property
    def error_message(self):
        """Gets the error_message of this Health.  # noqa: E501


        :return: The error_message of this Health.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this Health.


        :param error_message: The error_message of this Health.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def healthy(self):
        """Gets the healthy of this Health.  # noqa: E501


        :return: The healthy of this Health.  # noqa: E501
        :rtype: bool
        """
        return self._healthy

    @healthy.setter
    def healthy(self, healthy):
        """Sets the healthy of this Health.


        :param healthy: The healthy of this Health.  # noqa: E501
        :type: bool
        """

        self._healthy = healthy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Health, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Health):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
